@@ -154,6 +154,18 @@ class AppearanceGeneratorHelper
     {
         value = apValue;
 
+        // Treat multiline field values in single lines as single lime values.
+        // This is in line with how Adobe Reader behaves when enetring text
+        // interactively but NOT how it behaves when the field value has been
+        // set programmatically and Reader is forced to generate the appearance
+        // using PDAcroForm.setNeedAppearances
+        // see PDFBOX-3911
+        if (field instanceof PDTextField && !((PDTextField) field).isMultiline())
+        {
+            value = apValue.replaceAll(
+                    "\\u000D\\u000A|[\\u000A\\u000B\\u000C\\u000D\\u0085\\u2028\\u2029]", " ");
+        }
+
         for (PDAnnotationWidget widget : field.getWidgets())
         {
             // some fields have the /Da at the widget level if the
@@ -411,7 +423,7 @@ class AppearanceGeneratorHelper
         PDFont font = field.getAppearanceFont();
 
         // fallback to default appearance
-        if(font == null)
+        if (font == null)
         {
             font = defaultAppearance.getFont();
         }
@@ -504,7 +516,6 @@ class AppearanceGeneratorHelper
             formatter.format();
         }
 
-
         contents.endTextIfRequired();
         contents.restoreGraphicsState();
     }
@@ -589,7 +600,6 @@ class AppearanceGeneratorHelper
 
         float xOffset = combWidth / 2;
 
-
         contents.saveGraphicsState();
         contents.setFont(font, fontSize);
 
